==> nextcloud-app-mail-5.5.10-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/bn_BD.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "গুরুত্বপূর্ণ",
    "Work" : "কর্মস্থল",
    "Personal" : "ব্যক্তিগত",
    "Mail" : "মেইল",
    "Save" : "সংরক্ষণ",
    "Connect" : "সংযুক্ত হও",
    "Name" : "নাম",
    "Password" : "কূটশব্দ",
    "None" : "কোনটিই নয়",
    "Go back" : "ফিরে যাও",
    "Cancel" : "বাতির",
    "Accounts" : "Accounts",
    "General" : "সাধারণ",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Delete" : "মুছে",
    "Search" : "Search",
    "Send" : "পাঠাও",
    "Refresh" : "নবোদ্যম",
    "Ok" : "তথাস্তু",
    "Choose" : "বেছে নিন",
    "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
    "Favorite" : "প্রিয়জন",
    "Read" : "পড়",
    "Edit tags" : "ট্যাগ সম্পাদনা",
    "Back" : "পেছনে যাও",
    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
    "Description" : "বিবরণ",
    "Create" : "তৈরী কর",
    "Select" : "সিলেক্ট",
    "Comment" : "মন্তব্য",
    "Remove" : "অপসারণ",
    "Today" : "আজ",
    "Other" : "অন্যান্য",
    "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
    "Move" : "Move",
    "Folder name" : "ফোলডারের নাম",
    "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
    "Rename" : "পূনঃনামকরণ",
    "Clear cache" : "ক্যাশে পরিষ্কার কর",
    "Reply" : "জবাব",
    "Add" : "যোগ করুন",
    "Close" : "বন্ধ",
    "Date" : "Date",
    "Tags" : "ট্যাগ",
    "Help" : "সহায়িকা",
    "Actions" : "পদক্ষেপসমূহ",
    "delete" : "মুছে ফেল",
    "Edit" : "সম্পাদনা",
    "Reset" : "পূণঃনির্ধানণ",
    "Client ID" : "ক্লায়েন্ট পরিচিতি",
    "User" : "User",
    "Host" : "হোস্ট",
    "Port" : "পোর্ট",
    "Group" : "গোষ্ঠীসমূহ",
    "Shared" : "ভাগাভাগিকৃত",
    "Shares" : "ভাগাভাগি",
    "All" : "সবাই",
    "Favorites" : "প্রিয়জন"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.5.15-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/bn_BD.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "গুরুত্বপূর্ণ",
    "Work" : "কর্মস্থল",
    "Personal" : "ব্যক্তিগত",
    "Mail" : "মেইল",
    "Save" : "সংরক্ষণ",
    "Connect" : "সংযুক্ত হও",
    "Name" : "নাম",
    "Password" : "কূটশব্দ",
    "None" : "কোনটিই নয়",
    "Go back" : "ফিরে যাও",
    "Cancel" : "বাতির",
    "General" : "সাধারণ",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Delete" : "মুছে",
    "Search" : "Search",
    "Send" : "পাঠাও",
    "Refresh" : "নবোদ্যম",
    "Ok" : "তথাস্তু",
    "Choose" : "বেছে নিন",
    "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
    "Favorite" : "প্রিয়জন",
    "Read" : "পড়",
    "Edit tags" : "ট্যাগ সম্পাদনা",
    "Back" : "পেছনে যাও",
    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
    "Description" : "বিবরণ",
    "Create" : "তৈরী কর",
    "Select" : "সিলেক্ট",
    "Comment" : "মন্তব্য",
    "Remove" : "অপসারণ",
    "Today" : "আজ",
    "Other" : "অন্যান্য",
    "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
    "Move" : "Move",
    "Folder name" : "ফোলডারের নাম",
    "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
    "Rename" : "পূনঃনামকরণ",
    "Clear cache" : "ক্যাশে পরিষ্কার কর",
    "Reply" : "জবাব",
    "Add" : "যোগ করুন",
    "Close" : "বন্ধ",
    "Date" : "Date",
    "Tags" : "ট্যাগ",
    "Help" : "সহায়িকা",
    "Actions" : "পদক্ষেপসমূহ",
    "delete" : "মুছে ফেল",
    "Edit" : "সম্পাদনা",
    "Reset" : "পূণঃনির্ধানণ",
    "Client ID" : "ক্লায়েন্ট পরিচিতি",
    "User" : "User",
    "Host" : "হোস্ট",
    "Port" : "পোর্ট",
    "Group" : "গোষ্ঠীসমূহ",
    "Shared" : "ভাগাভাগিকৃত",
    "Shares" : "ভাগাভাগি",
    "All" : "সবাই",
    "Favorites" : "প্রিয়জন",
    "Accounts" : "Accounts"
},
"nplurals=2; plural=(n != 1);");
